# `neatnet`: Street Geometry Processing Toolkit

[![Continuous Integration](https://github.com/uscuni/neatnet/actions/workflows/testing.yml/badge.svg)](https://github.com/uscuni/neatnet/actions/workflows/testing.yml) [![codecov](https://codecov.io/gh/uscuni/neatnet/graph/badge.svg?token=GFISMU0WPS)](https://codecov.io/gh/uscuni/neatnet)

## Introduction

## Documentation

## Examples

```py
import neatnet

simplified = neatnet.simplify_network(gdf)
```

## Contribution

See our guidelines in [`CONTRIBUTING.md`](https://github.com/uscuni/neatnet/blob/main/CONTRIBUTING.md).

## Recommended Citation

---------------------------------------

This package developed & and maintained by:
* [Martin Fleischmann](https://github.com/martinfleis)
* [Anastassia Vybornova](https://github.com/anastassiavybornova)
* [James D. Gaboardi](https://github.com/jGaboardi)

Copyright (c) 2024-, neatnet Developers
